# eric7.Plugins.UiExtensionPlugins.Translator.TranslatorEngines.__init__

Package containing the various translation engines.

### Global Attributes

None

### Classes

None

### Functions

engineDisplayName | Module function to get a translated name for an engine.
getEngineIcon | Module function to get the icon of the named engine.
getKeyUrl | Module function to get an URL to request a user key.
getTranslationEngine | Module function to instantiate an engine object for the named service.
supportedEngineNames | Module function to get the list of supported translation engines.

## engineDisplayName

engineDisplayName(name)

Module function to get a translated name for an engine.

name (str)
  name of a translation engine

Return:
  translated engine name

Return Type:
  str

Up

## getEngineIcon

getEngineIcon(name)

Module function to get the icon of the named engine.

name (str)
  name of the translation engine

Return:
  engine icon

Return Type:
  QIcon

Up

## getKeyUrl

getKeyUrl(name)

Module function to get an URL to request a user key.

name (str)
  name of the online translation service

Return:
  key request URL

Return Type:
  str

Up

## getTranslationEngine

getTranslationEngine(name, plugin, parent=None)

Module function to instantiate an engine object for the named service.

name (str)
  name of the online translation service
plugin (TranslatorPlugin)
  reference to the plugin object
parent (QObject)
  reference to the parent object

Return:
  translation engine

Return Type:
  TranslatorEngine

Up

## supportedEngineNames

supportedEngineNames()

Module function to get the list of supported translation engines.

Return:
  names of supported engines

Return Type:
  list of str

Up